@@ -1,13 +1,14 @@
 import logging
+from typing import Dict, Any
 
 import aioredis
 import orjson
 from aioredis import RedisError
-from aioredlock import Aioredlock, Lock
+from aioredis.lock import Lock, LockError
 from httpx import HTTPError
 
 from ._collector import PeachCollector
-from ._utils import timestamp, retry_with_backoff, RetryException, retry_secs
+from ._utils import retry_with_backoff, RetryException, retry_secs, check_event
 
 logger = logging.getLogger(__name__)
 
@@ -26,7 +27,7 @@ class PeachCollectorQueue:
         self.collector = collector
         self.batch_size = batch_size
         self.redis_url = redis_url
-        self.conn = None
+        self.conn = aioredis.from_url(self.redis_url, encoding="utf-8", decode_responses=True)
         self.lock_manager = None
         self.name = name
         self.lock_name = f"{self.name}_lock"
@@ -38,23 +39,16 @@ class PeachCollectorQueue:
             < self.lock_ttl_secs
         )
 
-    async def init_redis_conn(self):
-        if not self.conn:
-            self.conn = await aioredis.create_redis_pool(self.redis_url)
-
-    async def close_redis_conn(self):
+    def close_redis_conn(self):
         if self.conn:
             self.conn.close()
-            await self.conn.wait_closed()
             self.conn = None
 
-    async def push_event(self, event):
+    async def push_event(self, event: Dict[str, Any]):
         """
         Adds event to queue. Make sure it is json serializable
         """
-        await self.init_redis_conn()
-        event = {**{"timestamp": timestamp()}, **event}
-        await self.conn.rpush(self.name, orjson.dumps(event))
+        await self.conn.rpush(self.name, orjson.dumps(check_event(event)))  # type: ignore
 
     async def drain(self) -> bool:
         """
@@ -84,17 +78,13 @@ class PeachCollectorQueue:
         return num_sent == len(events)
 
     async def _acquire_lock(self) -> Lock:
-        await self.init_redis_conn()
-        if not self.lock_manager:
-            urls = self.redis_url if isinstance(self.redis_url, list) else [self.redis_url]
-            self.lock_manager = Aioredlock(urls)
-        return await self.lock_manager.lock(self.lock_name, lock_timeout=self.lock_ttl_secs)
+        lock = self.conn.lock(self.lock_name, timeout=self.lock_ttl_secs, blocking_timeout=0.1)
+        if not await lock.acquire():
+            raise LockError("Couldn't get hold of lock")
+        return lock
 
     async def _release_lock(self, lock: Lock):
-        if self.lock_manager and lock:
-            await self.lock_manager.unlock(lock)
-            await self.lock_manager.destroy()
-            self.lock_manager = None
+        return await lock.release()
 
     async def _load_events_from_redis(self):
         try:
@@ -109,6 +99,7 @@ class PeachCollectorQueue:
         :returns An int with how many we've many we've been able to send
         """
         num_sent = 0
+        self.collector.events = []
         try:
             # fmt: off
             batches = [
@@ -148,17 +139,15 @@ class PeachCollectorQueue:
             )
 
     def _log_results(self, events: list, num_sent: int):
-        if len(events):
-            if num_sent == len(events):
-                logger.info(f"{num_sent} events sent to Peach")
-            else:
-                if num_sent:
-                    logger.warning(
-                        f"We were only able to send {num_sent} out of {len(events)} events to Peach"
-                    )
-                else:
-                    logger.warning(
-                        f"We weren't able to send any events to Peach. {len(events)} waiting"
-                    )
-        else:
+        if not len(events):
             logger.info("No events waiting to be sent to Peach")
+            return
+        if num_sent == len(events):
+            logger.info(f"{num_sent} events sent to Peach")
+            return
+        if num_sent:
+            logger.warning(
+                f"We were only able to send {num_sent} out of {len(events)} events to Peach"
+            )
+            return
+        logger.warning(f"We weren't able to send any events to Peach. {len(events)} waiting")
