@@ -1,31 +1,35 @@
 import aioredis
 import orjson
 import pytest
+import os
 from aioredis import RedisError
-from aioredlock import LockError
+from aioredis.lock import LockError
 from httpx import HTTPError, Request
 from pytest_httpx import HTTPXMock, to_response
 
 from peach_collector import PeachCollector, PeachCollectorQueue
 
 
+def redis_url():
+    return os.environ.get("REDIS_URL", "redis://localhost")
+
+
 @pytest.fixture()
 async def redis():
-    redis = await aioredis.create_redis_pool("redis://localhost")
+    redis = await aioredis.from_url(redis_url(), encoding="utf-8", decode_responses=True)
     await redis.flushall()
     yield redis
     redis.close()
-    await redis.wait_closed()
 
 
 @pytest.fixture()
 async def queue(redis):
     collector = PeachCollector("a-site-key", "an-app-id")
-    q = PeachCollectorQueue("redis://localhost", collector, name="my_q", batch_size=2)
+    q = PeachCollectorQueue(redis_url(), collector, name="my_q", batch_size=2)
     for i in range(1, 6):
-        await q.push_event({"foo": i})
+        await q.push_event({"type": "event-type", "foo": i})
     yield q
-    await q.close_redis_conn()
+    q.close_redis_conn()
 
 
 @pytest.mark.asyncio
@@ -57,7 +61,7 @@ async def test_peach_collector_queue_peach_failures(httpx_mock: HTTPXMock, redis
         nonlocal call_counter
         call_counter += 1
         if call_counter == 2:
-            raise HTTPError(message="boom", request=request)
+            raise HTTPError("boom")
         return to_response(json={"ok": 1})
 
     httpx_mock.add_callback(response)
@@ -70,12 +74,10 @@ async def test_peach_collector_queue_peach_failures(httpx_mock: HTTPXMock, redis
 @pytest.mark.asyncio
 async def test_peach_collector_queue_redis_lock(queue):
     lock = await queue._acquire_lock()
-    another_q = PeachCollectorQueue("redis://localhost", queue.collector, name="my_q")
+    another_q = PeachCollectorQueue(redis_url(), queue.collector, name="my_q")
     with pytest.raises(LockError):
         await another_q._acquire_lock()
-    await another_q.close_redis_conn()
     await queue._release_lock(lock)
-
     # Now that lock should be available
     await another_q._acquire_lock()
 
